.. image:: https://raw.githubusercontent.com/MinchinWeb/colourettu/master/docs/colourettu-logo-4x.png
    :align: center

Colourettu is a small collection of colour functions in Python. These can be used to determine the (relative) luminosity of a colour and the contrast between two colours. There is also the palette class for dealing with a 'list' of colours.

.. image:: https://img.shields.io/pypi/v/colourettu.svg?style=flat
    :target: https://pypi.python.org/pypi/colourettu/

.. monthly downloads -- https://img.shields.io/pypi/dm/colourettu.svg?style=flat

.. image:: https://api.travis-ci.org/MinchinWeb/colourettu.svg?branch=master
    :target: http://travis-ci.org/MinchinWeb/colourettu

.. image:: https://coveralls.io/repos/MinchinWeb/colourettu/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/MinchinWeb/colourettu?branch=master

.. image:: https://img.shields.io/pypi/l/colourettu.svg?style=flat
    :target: https://github.com/MinchinWeb/colourettu/blob/master/LICENSE

.. https://landscape.io/github/USERNAME/PROJECT/master/landscape.png

.. https://badge.waffle.io/USERNAME/PROJETC.png?label=ready&title=Ready

Installation
------------

::

    pip install colourettu

Documentation
-------------

Full documentation is available at http://minchin.ca/colourettu/

Changelog
---------

Full changelog is available at http://minchin.ca/colourettu/changelog.html

Links
-----

- Code, on GitHub: http://www.github.com/minchinweb/colourettu/
- Report a Bug! https://github.com/minchinweb/colourettu/issues
- Documentation: http://minchin.ca/colourettu/
- Listing on PyPI: https://pypi.python.org/pypi/colourettu

License
-------

*Colourettu* is licensed under the MIT license.
